#!/bin/sh
cd ../DriveAccess

for fn in *.c *.h; do
  echo Converting $fn to sjis...
  nkf -s -Lu $fn > tmp
  mv tmp $fn
done

